#!/bin/sh

# バージョン情報が記載されたファイル
ver_def_file="fjexsock.c"

# バージョン番号抽出のための席表現パターン
major_ver_defstr="ES_DRV_MAJOR_NO"
minor_ver_defstr="ES_DRV_MINOR_NO"

# パッケージに含む必要がある基本的なファイルリスト
# (スペース文字を含むファイルは入れないこと)
standard_file_list="\
	fjexsock.c \
	fjexsock_ioctl.h \
	fjexsock.spec \
	Makefile \
	gpl-2.0.txt \
"

# kmodtoolを使用する場合にパッケージに含む必要があるファイルリスト
# (スペース文字を含むファイルは入れないこと)
kmodtool_file_list="
      	kmodtool-fjexsock \
	kmodtool-fjexsock-filelist.txt \
"

# コマンドの使い方を表示する関数
function usage() {
	echo " Usage: $0 {rhel7|sles12|kmodtool}"
	echo "      rhel70   : make RPM for RHEL7"
	echo "      rhel71   : make RPM for RHEL7.1"
	echo "      sles12   : make RPM for SLES12"
	echo "      kmodtool : make RPM with kmodtool (defectiveness)"
}

# Cソースでdefineされた値を抽出する関数
#   第1引数：対象のソースコードファイル名
#   第2引数：抽出するdefine定義
function get_def_value() {
	grep -E "#define[[:space:]]+$2" "$1" | sed "s/[[:space:]]/ /g" | tr -s ' ' | cut -d ' ' -f 3
}


#### 以下処理 ####


# 引数の数チェック
if [ $# != 1 ]
then
	usage
	exit
fi

# 第１引数の文字列チェック
case $1 in
	"rhel70" | "rhel71" | "sles12")
		spec_file="fjexsock.""$1"".spec"
		file_list="$standard_file_list"
		break
		;;
	"kmodtool")
		spec_file="fjexsock.""$1"".spec"
		file_list="$standard_file_list $kmodtool_file_list"
		break
		;;
	*)
		usage
		exit
		;;
esac

# メジャーバージョンの取得
major_ver=$(get_def_value "$ver_def_file" "$major_ver_defstr")
if [ $major_ver = "" ]
then
	major_ver=0
fi

# マイナーバージョンの取得
minor_ver=$(get_def_value "$ver_def_file" "$minor_ver_defstr")
if [ $minor_ver = "" ]
then
	minor_ver=0
fi

package_name="fjexsock-""$major_ver"".""$minor_ver"

cp "$spec_file" "fjexsock.spec"

rm -rf "$package_name"
mkdir "$package_name"
cp -r $file_list "$package_name"
tar -czf "$package_name"".tar.gz" "$package_name"
rpmbuild -ta "$package_name"".tar.gz"
rm -rf "$package_name"{,".tar.gz"} "fjexsock.spec"

echo "RPMパッケージは「~/rpmbuild/RPMS/x86_64」に作られます。"

